@@ -101,7 +101,7 @@ class MuMIDIEncoding(MIDITokenizer):
                 count += 1
             self.max_bar_embedding = nb_bars
 
-        ticks_per_frame = midi.ticks_per_beat // max(self.beat_res.values())
+        ticks_per_frame = midi.ticks_per_beat / max(self.beat_res.values())
         ticks_per_bar = midi.ticks_per_beat * 4
 
         # Process notes of every tracks
@@ -203,7 +203,9 @@ class MuMIDIEncoding(MIDITokenizer):
 
         tokens = []
         for note in track.notes:
-            if note.pitch not in self.pitch_range:  # Notes to low or to high are discarded
+            if not track.is_drum and note.pitch not in self.pitch_range:
+                continue
+            if track.is_drum and note.pitch not in self.drum_pitch_range:
                 continue
             # Note
             velocity_index = (np.abs(self.velocity_bins - note.velocity)).argmin()
@@ -249,6 +251,8 @@ class MuMIDIEncoding(MIDITokenizer):
         :param time_division: MIDI time division / resolution, in ticks/beat (of the MIDI to create)
         :return: the midi object (miditoolkit.MidiFile)
         """
+        assert time_division % max(self.beat_res.values()) == 0, \
+            f'Invalid time division, please give one divisible by {max(self.beat_res.values())}'
         midi = MidiFile(ticks_per_beat=time_division)
         ticks_per_frame = time_division // max(self.beat_res.values())
 
